ProfileEntry

Enum ProfileEntry 

pub enum ProfileEntry<Start, Result> {
    Register {
        id: Id,
        metadata: Option<&'static Metadata<'static>>,
        parent: Option<Id>,
        start: Start,
    },
    Publish {
        id: Id,
        result: Result,
    },
}
Entry collected by Collector.

This is pure data transfer object, just storing information about span, and result of metrics calculation on span closing.

Variants



Register

Span entered — captures start state.

Fields

id: Id
metadata: Option<&'static Metadata<'static>>
parent: Option<Id>
start: Start


Publish

Span exited — captures measured result.

Fields

id: Id
result: Result